qermit.mitres
=============

.. currentmodule:: qermit.taskgraph.mitres.MitRes
.. autoclass:: qermit.taskgraph.mitres.MitRes
    :special-members:
    :members:

.. automethod:: qermit.taskgraph.mitres.backend_compile_circuit_shots_task_gen

.. automethod:: qermit.taskgraph.mitres.backend_handle_task_gen

.. automethod:: qermit.taskgraph.mitres.backend_res_task_gen

.. automethod:: qermit.taskgraph.mitres.gen_shot_split_MitRes

.. automethod:: qermit.taskgraph.mitres.split_shots_task_gen

.. automethod:: qermit.taskgraph.mitres.group_shots_task_gen